<?PHP // $Id$ 
      // enrol_paypal.php - created with Moodle 1.4.2 (2004083125)


$string['business'] = 'ŷس account Paypal';
$string['description'] = 'ҹ繡õ駤ѡ¹¤㹡¹͹֡Һ¹  ҵ駤 0 к¤¡͹֡   ҷ駹繤Ңͧ䫵 ö¹ŧѺԪ ¡õ駤Ԫ';
$string['enrolname'] = 'Paypal';
$string['parentlanguage'] = 'en';
$string['sendpaymentbutton'] = '觤ŧ¹ҹ Paypal';
$string['thischarset'] = 'TIS-620';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Thai';

?>
